# el-pkgutils.sh --- functions that may be useful for packaging 
# Emacs Lisp modules, a shell (bash) interface to el-pkgutils.el.
#
# Copyright (C) 2002 ALT Linux Team
#
# Author: Ivan Zakharyaschev <imz@altlinux.ru>
# Last change: 24 Feb 2002
#
# This code is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2, or (at your option)
# any later version.
#
# Commentary:
#
# Source this file in your RPM spec-file's %install section to
# be able to use the functions; example:
#
# . /usr/lib/emacs/el-pkgutils.sh
# fraction \
#    '(el-without-elc "/usr/share/emacs/21.1") "main-filelist"' \
#    '(el-with-elc "/usr/share/emacs/21.1") "el-filelist"'

#set -x # DEBUG

if [[ ! "$EMACS_BIN" ]]; then
    EMACS_BIN=emacs
fi

fraction() {
local emacs="$EMACS_BIN" el_mod=el-pkgutils.el

if [[ "$EL_PKGUTILS_ROOT" ]]; then
    if [[ "${EMACS_BIN#/}" == "$EMACS_BIN" ]]; then
	emacs="$EL_PKGUTILS_ROOT/usr/bin/$EMACS_BIN"
    fi
    #el_mod="$EL_PKGUTILS_ROOT/usr/share/emacs/site-lisp/$el_mod"
    export EMACSLOADPATH="$(find "$EL_PKGUTILS_ROOT"/usr/share/emacs -type d -printf '%p:')"
fi

"$emacs" -batch --no-site-file \
    -l "$el_mod"  -f batch-fraction-save-lists \
    "$@"
}

standard_fraction_el_elc() {
local mainList="$1".ls elList="$1"-el.ls
shift

for tree in "$@"; do 
    (
	tmp="$(mktemp elXXXXXX)"
	trap "rm -f $tmp" EXIT
	fraction "(el-with-elc \"$tree\") \"$tmp\""
	cat "$tmp" | sed -e "s:^:$RPM_BUILD_ROOT:" \
	    | xargs gzip -9 -v 2>&1 | sed -e 's@:.*$@.gz@' | xargs zme
    ) || false

    fraction \
	"(dirs \"$tree\" \"%dir\") \"$mainList\" \"$elList\"" \
	"(elc \"$tree\") \"$mainList\"" \
	"(el-with-elc \"$tree\") \"$elList\"" \
	"(el-without-elc \"$tree\") \"$mainList\"" \
	"(etc \"$tree\") \"$mainList\""
done

}

# el-pkgutils.sh ends here
